DELLve Benchmark Service
========================

Getting Started
---------------

Install CLI tools:

```bash
# optional: virtualenv venv && source venv/bin/activate
pip install .
```

Check out CLI help:

```bash
dellve --help
```


[![Build Status](https://travis-ci.org/dellve/dellve_benchend.svg?branch=dev)](https://travis-ci.org/dellve/dellve_benchend)


[![Coverage Status](https://coveralls.io/repos/github/dellve/dellve_benchend/badge.svg?branch=master)](https://coveralls.io/github/dellve/dellve_benchend?branch=master)
